@@ -17,7 +17,11 @@
 // labels and tooltips. When one switches modes, the corresponding
 // label is displayed.
 
-enum ButtonModeFlags { ModeNormal = 0, ModeShift = 1, ModeHyperbolic = 2 };
+enum ButtonModeFlags {
+    ModeNormal = 0,
+    ModeShift = 1,
+    ModeHyperbolic = 2
+};
 
 // Each kcalc button can be in one of several modes.
 // The following class describes label, tooltip etc. for each mode...
